Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Provider ¶
func Provider() terraform.ResourceProvider
Provider returns a terraform.ResourceProvider.
Types ¶
type ArmClient ¶
type ArmClient struct {
// contains filtered or unexported fields
}
ArmClient contains the handles to all the specific Azure Resource Manager resource classes' respective clients.
type Config ¶
type Config struct {
ManagementURL string
SubscriptionID string
ClientID string
ClientSecret string
TenantID string
}
Config is the configuration structure used to instantiate a new Azure management client.
type ResourceID ¶
type ResourceID struct {
SubscriptionID string
ResourceGroup string
Provider string
Path map[string]string
}
ResourceID represents a parsed long-form Azure Resource Manager ID with the Subscription ID, Resource Group and the Provider as top- level fields, and other key-value pairs available via a map in the Path field.
Click to show internal directories.
Click to hide internal directories.